@@ -16,7 +16,6 @@
  */
 
 #pragma once
-#include <QtGlobal>
 class QIODevice;
 namespace KTnef
 {
@@ -25,5 +24,5 @@ namespace KTnef
  * @param input compressed input data.
  * @param output decompressed output data.
  */
-Q_REQUIRED_RESULT int lzfu_decompress(QIODevice *input, QIODevice *output);
+[[nodiscard]] int lzfu_decompress(QIODevice *input, QIODevice *output);
 }
